AZMP Scotian Shelf SST from Satellite (ea_data)
Source:R/data-documentation.R
azmp_satellite_temperature.RdSea surface temperature (SST) from satellite data for the Scotian Shelf, covering NAFO Divisions 4X, 4V, and 4W. Data are averaged from satellite observations and are crucial for fisheries and climate analyses.
Usage
data(azmp_satellite_temperature)Format
An ea_data object:
- data
A tibble with columns:
year: Numeric yearregion: Character NAFO area namemean_value: Numeric sea surface temperature (°C)
- meta
A named list, including:
data_type: "Sea Surface Temperature"region: "Scotian Shelf"location_descriptor: "NAFO 4X-4W"units: "°C"species:NAsource_citation: "DFO AZMP, through azmpdata package https://github.com/casaultb/azmpdata/"