Skip to contents

Prints a message reminding users to cite the marea package in their work.

Usage

marea_citation_reminder()

Examples

marea_citation_reminder()
#> Thank you for using marea!
#> Please cite this package in your work:
#> 
#> To cite marea in publications use:
#> 
#>   Jamie C. Tam, Benoit Casault, Stephanie Clay et al. (). marea:
#>   Maritime Ecosystem Approach R Package. R package version 1.0.0.9000.
#>   https://doi.org/10.5281/zenodo.15706086
#> 
#> We appreciate citations as they help us secure funding for continued
#> development.