An S4 Class for Spatio-Temporal Environmental Assessment Data
Source:R/ea_spatial_class.R
ea_spatial-class.RdThe ea_spatial class is a container for environmental assessment data that
has a spatial component. It is designed to be flexible, supporting vector
data via sf objects and raster data via stars or terra::SpatRaster
objects.
It standardizes the data by encapsulating a spatial object in the data slot
and a list of descriptive information in the meta slot.
Slots
metaA named list containing metadata. Expected fields include
data_type,region,time_descriptor,units,source_citation, andoriginal_value_col.dataA spatial object. Must be of class
sf,stars, orSpatRaster. The object is expected to have a column or layer namedvaluecontaining the primary data.
See also
ea_spatial for the constructor function.
ea.subset.spatial for a filtering helper function.