The SOI is a monthly measure of the seasonal atmospheric pressure differences between Tahiti and Darwin, a leading indicator of El Niño/La Niña conditions.
Usage
data(soi)Format
An ea_data object:
- data
Tibble with:
year: Yearmonth: Month (1–12)value: SOI value (unitless index)
- meta
Metadata includes
data_type: "Southern Oscillation Index"region: "South Pacific"location_descriptor: "Tahiti-Darwin"units: "index"source_citation: "NOAA CPC"original_value_col: "anomaly"